harrier
=======

|BuildStatus| |Coverage| |pypi|

A better static site generator.

See `documentation`_ for more details.

.. |BuildStatus| image:: https://travis-ci.org/samuelcolvin/harrier.svg?branch=master
   :target: https://travis-ci.org/samuelcolvin/harrier
.. |Coverage| image:: https://codecov.io/gh/samuelcolvin/harrier/branch/master/graph/badge.svg
   :target: https://codecov.io/gh/samuelcolvin/harrier
.. |pypi| image:: https://img.shields.io/pypi/v/harrier.svg
   :target: https://pypi.python.org/pypi/harrier
.. _documentation: https://harrier.helpmanual.io/
